@@ -395,23 +395,23 @@ class WordType(models.Model):
         for s in ur:
             posq = WordType.objects.filter(underlying__Ordering=s.Ordering,underlying__SegmentType=s.SegmentType)
             pos = 0.0
-            for p in posq:
-                pos += p.getFreq()
+            for pr in posq:
+                pos += pr.getFreq()
             allposq = WordType.objects.filter(underlying__Ordering=s.Ordering)
             allpos = 0.0
-            for p in allposq:
-                allpos += p.getFreq()
+            for pr in allposq:
+                allpos += pr.getFreq()
             SPhoneProb += float(pos)/float(allpos)
         if len(ur) > 1:
             for i in xrange(len(ur)-1):
                 posq = WordType.objects.filter(underlying__Ordering=ur[i].Ordering,underlying__SegmentType=ur[i].SegmentType).filter(underlying__Ordering=ur[i+1].Ordering,underlying__SegmentType=ur[i+1].SegmentType)
                 pos = 0.0
-                for p in posq:
-                    pos += p.getFreq()
+                for pr in posq:
+                    pos += pr.getFreq()
                 allposq = WordType.objects.filter(underlying__Ordering=ur[i].Ordering).filter(underlying__Ordering=ur[i+1].Ordering)
                 allpos = 0.0
-                for p in allposq:
-                    allpos += p.getFreq()
+                for pr in allposq:
+                    allpos += pr.getFreq()
                 BiPhoneProb += float(pos)/float(allpos)
         self.SPhonoProb,self.BiPhonoProb = SPhoneProb,BiPhoneProb
         self.save()
@@ -534,7 +534,7 @@ class WordToken(models.Model):
             begin,end = self.getStressedVowelInfo()
             ceiling = self.getCeiling()
             nformants = self.getNFormants()
-            out = p.getFormants(fetch_buckeye_resource("Speakers/"+path+'.wav'),begin,end,nformants,ceiling)
+            out = p.get_formants(fetch_buckeye_resource("Speakers/"+path+'.wav'),begin,end,nformants,ceiling)
             dur = float(end)-float(begin)
             if dur > 0.0:
                 fones = [x['F1(Hz)'] for x in out if x['F1(Hz)'] != '--undefined--' and float(x['time(s)'])/dur> 0.25 and float(x['time(s)'])/dur < 0.75]
@@ -802,18 +802,18 @@ class WordToken(models.Model):
         ceiling = self.getCeiling()
         nformants = self.getNFormants()
         if not os.path.isfile(wavpath):
-            p.extractToken(filename, beg, end, wavpath)
+            p.extract_token(filename, beg, end, wavpath)
         if not os.path.isfile(waveformpath):
-            p.waveformPic(wavpath,','.join([str(x.End-self.Begin) for x in self.segmenttoken_set.all()]))
+            p.waveform_pic(wavpath,','.join([str(x.End-self.Begin) for x in self.segmenttoken_set.all()]))
             im = Image.open(wfepspath)
             im.save(waveformpath)
             os.remove(wfepspath)
-        p.spectroPic(wavpath,1,nformants,ceiling,','.join([str(x.End-self.Begin) for x in self.segmenttoken_set.all()]))
+        p.spectro_pic(wavpath,1,nformants,ceiling,','.join([str(x.End-self.Begin) for x in self.segmenttoken_set.all()]))
         im = Image.open(specepspath)
         im.save(specpath)
         os.remove(specepspath)
         if not os.path.isfile(outpath):
-            p.convertMP3(wavpath)
+            p.convert_MP3(wavpath)
         #decoder  =  timeside.decoder.FileDecoder(wavpath)
         #grapher  =  timeside.grapher.Waveform()
         #spectrogram = timeside.grapher.Spectrogram(width=400,height=100)
@@ -903,9 +903,7 @@ class WordToken(models.Model):
         if form['measure'] == 'S':
             ceiling = self.getCeiling()
             nformants = self.getNFormants()
-            p.getFormants(self.getDialogPath(),beg,end,nformants,ceiling)
-            out = p.readPraatOut()
-            out = p.formatOutput(out, outline, end-beg,getMid=False)
+            p.get_formants(self.getDialogPath(),beg,end,nformants,ceiling)
             return out
         else:
             outline['F1'] = self.getStrF1()
